package javax.swing.text.html;

import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.Graphics;
import javax.swing.text.Element;

public class ListView extends BlockView
{
    private StyleSheet.ListPainter listPainter;
    
    public ListView(Element element) {
        super(element, 1);
    }
    
    @Override
    public float getAlignment(int i) {
        switch (i) {
            case 0: {
                return 0.5f;
            }
            case 1: {
                return 0.5f;
            }
            default: {
                throw new IllegalArgumentException("Invalid axis: " + i);
            }
        }
    }
    
    @Override
    public void paint(Graphics graphics, Shape a) {
        super.paint(graphics, a);
        Rectangle bounds = a.getBounds();
        Rectangle clipBounds = graphics.getClipBounds();
        if (clipBounds.x + clipBounds.width < bounds.x + this.getLeftInset()) {
            Rectangle insideAllocation = this.getInsideAllocation(a);
            int viewCount = this.getViewCount();
            int n = clipBounds.y + clipBounds.height;
            int i = 0;
            while (i < viewCount) {
                bounds.setBounds(insideAllocation);
                this.childAllocation(i, bounds);
                if (bounds.y < n) {
                    if (bounds.y + bounds.height >= clipBounds.y) {
                        this.listPainter.paint(graphics, (float)bounds.x, (float)bounds.y, (float)bounds.width, (float)bounds.height, this, i);
                    }
                    ++i;
                }
                else {
                    break;
                }
            }
        }
    }
    
    @Override
    protected void paintChild(Graphics g, Rectangle alloc, int index) {
        this.listPainter.paint(g, (float)alloc.x, (float)alloc.y, (float)alloc.width, (float)alloc.height, this, index);
        super.paintChild(g, alloc, index);
    }
    
    @Override
    protected void setPropertiesFromAttributes() {
        super.setPropertiesFromAttributes();
        this.listPainter = this.getStyleSheet().getListPainter(this.getAttributes());
    }
}
